--
--	bale spawn specialization
--
-- 	by baron
--

BaleSpawner = {};

function BaleSpawner.prerequisitesPresent(specializations)
    return true;
end;

function BaleSpawner:load(xmlFile)

	self.baleParam = {};
	self.baleParam.fillType 	= Utils.getNoNil(Fillable.fillTypeNameToInt[getXMLString(xmlFile,"vehicle.stack#fillType")],Fillable.FILLTYPE_WHEAT_WINDROW);
	self.baleParam.fillLevel   	= Utils.getNoNil(getXMLInt(xmlFile,"vehicle.stack#fillLevel"),4000);
	self.baleParam.isRoundBale 	= Utils.getNoNil(getXMLBool(xmlFile,"vehicle.stack#isRoundBale"),false);

	if self.baleParam.isRoundBale then 	--round bale dimensions
		self.baleParam.width    = 1.12;
		self.baleParam.height   = 0.0;
		self.baleParam.length   = 0.0;
		self.baleParam.diameter = 1.3;
	else 								--square bale dimensions
		self.baleParam.width    = 1.2;
		self.baleParam.height   = 0.9;
		self.baleParam.length   = 2.4;
		self.baleParam.diameter = 0.0;
	end;
	
	self.bale_indices = {};
	
	local count = 0;
	while true do
		local key = "vehicle.stack.bale("..tostring(count)..")";
				
		if not hasXMLProperty(xmlFile,key) then
			break;
		end;
		
		local index = Utils.indexToObject(self.components,getXMLString(xmlFile,key.."#index"));
		table.insert(self.bale_indices,index);
		
		count = count + 1;
	end;
end;

function BaleSpawner:delete()
end;

function BaleSpawner:mouseEvent(posX, posY, isDown, isUp, button)
end;

function BaleSpawner:keyEvent(unicode, sym, modifier, isDown)
end;

function BaleSpawner:update(dt)

	if self.isServer and g_currentMission.vehiclesToDelete[self] == nil then --make sure this stack is not sold
				
		local baleType = BaleUtil.getBale(self.baleParam.fillType,self.baleParam.width,self.baleParam.height,self.baleParam.length,self.baleParam.diameter,self.baleParam.isRoundBale);

		for k in pairs(self.bale_indices) do --spawn this stack
			local x,y,z 	= getWorldTranslation(self.bale_indices[k]);
			local rx,ry,rz 	= getWorldRotation	 (self.bale_indices[k]);
			
			local bale = Bale:new(self.isServer,self.isClient);
			bale:load(Utils.getFilename(baleType.filename, self.baseDirectory),x,y,z,rx,ry,rz,self.baleParam.fillLevel);
			bale:register();
		end;
		--remove this dummy vehicle
		g_currentMission:removeVehicle(self);
	end;
end;

function BaleSpawner:updateTick(dt)
end;

function BaleSpawner:draw()
end;